@@ -6,6 +6,8 @@ from AsteriskCommandApi.commons.asterisk_action import Action
 
 @attr.s(kw_only=True)
 class AsteriskCommand:
+    Action = attr.ib(default="")
+    ActionID = attr.ib(default="")
     auxiliar_commands = attr.ib(default=attr.Factory(list))
     Variables = attr.ib(default=attr.Factory(dict))
     is_asterisk_command = attr.ib(default=attr.Factory(bool, True))
